@@ -1,5 +1,6 @@
 from functools import wraps
 from .exceptions import PyCondition, PyConditionError
+from .inspector import Gadget
 
 from .stage import Stage
 
@@ -7,6 +8,14 @@ class PostCondition( object ):
   def __call__( self, func ):
     stage = Stage()
     self.name = "%s.%s" % ( func.__module__, func.__name__ )
+
+    gadget = Gadget( func )
+    doc = gadget.gogoDoc()
+    if( not doc and stage.name == "Dev" ):
+      doc = ""
+
+    doc += "%s - %s\n" % ( self.name, self.__class__.__name__ )
+    func.__doc__ = doc
     @wraps( func )
     def wrapper( *args, **kwargs ):
       returnValue = func( *args, **kwargs )
